@@ -205,8 +205,7 @@ func requireGoMod(tb testing.TB) {
 	require.NoError(tb, err)
 	require.Contains(tb, string(mod), `module foo
 
-go 1.20
-`)
+go 1.21`)
 }
 
 func fakeGoModAndSum(tb testing.TB, module string) {
