@@ -6,6 +6,7 @@ import (
 	"testing"
 
 	"github.com/goreleaser/goreleaser/internal/artifact"
+	"github.com/goreleaser/goreleaser/internal/skips"
 	"github.com/goreleaser/goreleaser/internal/testctx"
 	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
@@ -418,16 +419,16 @@ func doTestRunPipeConventionalNameTemplate(t *testing.T, snapshot bool) {
 		format := pkg.Format()
 		require.NotEmpty(t, format)
 		require.Contains(t, []string{
-			prefix + "-1.0.0.aarch64.rpm",
-			prefix + "-1.0.0.armv6hl.rpm",
-			prefix + "-1.0.0.armv7hl.rpm",
-			prefix + "-1.0.0.i386.rpm",
-			prefix + "-1.0.0.mips.rpm",
-			prefix + "-1.0.0.mips.rpm",
-			prefix + "-1.0.0.x86_64.rpm",
-			prefix + "-1.0.0.x86_64v2.rpm",
-			prefix + "-1.0.0.x86_64v3.rpm",
-			prefix + "-1.0.0.x86_64v4.rpm",
+			prefix + "-1.0.0-1.aarch64.rpm",
+			prefix + "-1.0.0-1.armv6hl.rpm",
+			prefix + "-1.0.0-1.armv7hl.rpm",
+			prefix + "-1.0.0-1.i386.rpm",
+			prefix + "-1.0.0-1.mips.rpm",
+			prefix + "-1.0.0-1.mips.rpm",
+			prefix + "-1.0.0-1.x86_64.rpm",
+			prefix + "-1.0.0-1.x86_64v2.rpm",
+			prefix + "-1.0.0-1.x86_64v3.rpm",
+			prefix + "-1.0.0-1.x86_64v4.rpm",
 			prefix + "_1.0.0_aarch64.apk",
 			prefix + "_1.0.0_amd64.deb",
 			prefix + "_1.0.0_amd64v2.deb",
@@ -1327,7 +1328,7 @@ func TestSkipSign(t *testing.T) {
 	})
 
 	t.Run("skip sign set", func(t *testing.T) {
-		ctx.SkipSign = true
+		skips.Set(ctx, skips.Sign)
 		require.NoError(t, Pipe{}.Run(ctx))
 	})
 }
